@@ -32,6 +32,8 @@ pub enum Error {
     InvalidTime,
     #[error("invalid format is passed to Balloon")]
     InvalidFormat,
+    #[error("invalid format is passed to Balloon")]
+    VerificationFailed,
 }
 
 pub use blake3::Hash;
@@ -240,15 +242,15 @@ pub fn verify(
     space: usize,
     time: usize,
     delta: usize,
-) -> Result<bool, Error> {
+) -> Result<(), Error> {
     match balloon(passy, salty, space, time, delta) {
         //no errors continue
         Ok(res) => {
             //do we have a match
             match compare_ct(res.as_bytes(), val.as_bytes()) {
-                Some(_) => Ok(false),
+                Some(_) => Err(Error::VerificationFailed),
                 //no res means match
-                None => Ok(true),
+                None => Ok(()),
             }
         }
 
@@ -280,6 +282,6 @@ mod tests {
         let password = [0u8, 1u8, 2u8, 3u8, 0u8, 1u8, 2u8, 3u8];
         let salt = [0u8, 1u8, 2u8, 3u8, 3u8];
         let test = balloon(&password, &salt, 24, 18, 5).unwrap();
-        assert!(verify(&test, &password, &salt, 24, 18, 5).unwrap());
+        assert!(verify(&test, &password, &salt, 24, 18, 5).is_ok());
     }
 }
